@@ -950,7 +950,7 @@ sub format_macro
 	    $one_line = $leading_space;
 	    $item_count = 0;
 	}
-	$one_line .= "$item ";
+	$one_line .= ($item_count ? ' ' : '' ) . "$item";
 	$item_count++;
     };
     # Add last line
